/// <reference types="node" />
import { AddFlagFn } from './cli';
import { Server, IncomingMessage } from 'http';
import { HttpRequestHandler, PostGraphileOptions } from '../interfaces';
import { WithPostGraphileContextFn } from './withPostGraphileContext';
import * as graphql from 'graphql';
export declare type HookFn<T> = (arg: T, context: {}) => T;
export declare type PluginHookFn = <TArgument, TContext = {}>(hookName: string, argument: TArgument, context?: TContext) => TArgument;
export interface PostGraphileHTTPResult {
    statusCode?: number;
    result?: object;
    errors?: Array<object>;
    meta?: object;
}
export interface PostGraphileHTTPEnd {
    statusCode?: number;
    result: object | Array<object>;
}
export interface PostGraphilePlugin {
    init?: HookFn<null>;
    pluginHook?: HookFn<PluginHookFn>;
    'cli:flags:add:standard'?: HookFn<AddFlagFn>;
    'cli:flags:add:schema'?: HookFn<AddFlagFn>;
    'cli:flags:add:errorHandling'?: HookFn<AddFlagFn>;
    'cli:flags:add:plugins'?: HookFn<AddFlagFn>;
    'cli:flags:add:noServer'?: HookFn<AddFlagFn>;
    'cli:flags:add:webserver'?: HookFn<AddFlagFn>;
    'cli:flags:add:jwt'?: HookFn<AddFlagFn>;
    'cli:flags:add'?: HookFn<AddFlagFn>;
    'cli:flags:add:deprecated'?: HookFn<AddFlagFn>;
    'cli:flags:add:workarounds'?: HookFn<AddFlagFn>;
    'cli:library:options'?: HookFn<{}>;
    'cli:server:middleware'?: HookFn<HttpRequestHandler>;
    'cli:server:created'?: HookFn<Server>;
    'cli:greeting'?: HookFn<Array<string | null | void>>;
    'postgraphile:options'?: HookFn<PostGraphileOptions>;
    'postgraphile:validationRules:static'?: HookFn<ReadonlyArray<typeof graphql.specifiedRules>>;
    'postgraphile:graphiql:html'?: HookFn<string>;
    'postgraphile:http:handler'?: HookFn<IncomingMessage>;
    'postgraphile:http:result'?: HookFn<PostGraphileHTTPResult>;
    'postgraphile:http:end'?: HookFn<PostGraphileHTTPEnd>;
    'postgraphile:httpParamsList'?: HookFn<Array<object>>;
    'postgraphile:validationRules'?: HookFn<ReadonlyArray<typeof graphql.specifiedRules>>;
    'postgraphile:middleware'?: HookFn<HttpRequestHandler>;
    withPostGraphileContext?: HookFn<WithPostGraphileContextFn>;
}
export declare function makePluginHook(plugins: Array<PostGraphilePlugin>): PluginHookFn;
export declare function pluginHookFromOptions(options: PostGraphileOptions): PluginHookFn;
